==> haskell-tuple-0.3.0.2-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tuple
version:              0.3.0.2
visibility:           public
id:                   tuple-0.3.0.2-AmhAG29ToPkDYkusNpep5a
key:                  tuple-0.3.0.2-AmhAG29ToPkDYkusNpep5a
license:              BSD-3-Clause
copyright:            2014 Lennart Augustsson
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            stable
synopsis:             Various functions on tuples
description:
    Various useful functions on tuples, overloaded on tuple size.

category:             Data
abi:                  d57403aadda59a802c89ffcd2d284749
exposed:              True
exposed-modules:
    Data.Tuple.All Data.Tuple.Curry Data.Tuple.Select
    Data.Tuple.Sequence Data.Tuple.Update

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tuple
hs-libraries:         HStuple-0.3.0.2-AmhAG29ToPkDYkusNpep5a
depends:              OneTuple-0.4.2-CoESLlucJHKJQHE2Fjo6f3 base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-tuple/html/tuple.haddock
haddock-html:         /usr/share/doc/haskell-tuple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tuple-0.3.0.2-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tuple
version:              0.3.0.2
visibility:           public
id:                   tuple-0.3.0.2-GETvmorbJfOAUIje2KHgO1
key:                  tuple-0.3.0.2-GETvmorbJfOAUIje2KHgO1
license:              BSD-3-Clause
copyright:            2014 Lennart Augustsson
maintainer:           Lennart Augustsson
author:               Lennart Augustsson
stability:            stable
synopsis:             Various functions on tuples
description:
    Various useful functions on tuples, overloaded on tuple size.

category:             Data
abi:                  98cfc4758ee755b611bd16820054821a
exposed:              True
exposed-modules:
    Data.Tuple.All Data.Tuple.Curry Data.Tuple.Select
    Data.Tuple.Sequence Data.Tuple.Update

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tuple-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tuple
hs-libraries:         HStuple-0.3.0.2-GETvmorbJfOAUIje2KHgO1
depends:              OneTuple-0.4.2-1k4Aw3RcTcmEWGKIqsFuzj base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-tuple/html/tuple.haddock
haddock-html:         /usr/share/doc/haskell-tuple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
